@@ -1,5 +1,5 @@
 /*
-  Copyright 2013 Mats Sjöberg
+  Copyright 2013-2015 Mats Sjöberg
   
   This file is part of the Pumpa programme.
 
@@ -25,6 +25,7 @@
 
 #include <QDesktopServices>
 #include <QMessageBox>
+#include <QTextDocument>
 
 //------------------------------------------------------------------------------
 
@@ -177,6 +178,8 @@ void FullObjectWidget::changeObject(QASAbstractObject* obj) {
                  m_actorWidget, SLOT(updateMenu()));
       disconnect(m_author, SIGNAL(changed()),
                  this, SLOT(updateFollowAuthorButton()));
+      disconnect(m_author, SIGNAL(changed()),
+		 this, SLOT(updateDeleteEditButtons()));
     }
 
     QASObjectList* ol = m_object->replies();
@@ -194,7 +197,7 @@ void FullObjectWidget::changeObject(QASAbstractObject* obj) {
 
   connect(m_object, SIGNAL(changed()), this, SLOT(onChanged()));
 
-  if (objType == "comment" || objType == "person") {
+  if (m_childWidget || objType == "person") {
     setLineWidth(1);
     setFrameStyle(QFrame::StyledPanel | QFrame::Plain);
     m_lessButton->setVisible(false);
@@ -234,10 +237,13 @@ void FullObjectWidget::changeObject(QASAbstractObject* obj) {
             m_actorWidget, SLOT(updateMenu()));
     connect(m_author, SIGNAL(changed()),
             this, SLOT(updateFollowAuthorButton()));
+    connect(m_author, SIGNAL(changed()),
+	    this, SLOT(updateDeleteEditButtons()));
   }
   
   updateFollowAuthorButton();
-
+  updateDeleteEditButtons();
+  
   m_followButton->setVisible(objType == "person");
 
   m_actor = m_object->asActor();
@@ -268,26 +274,20 @@ bool FullObjectWidget::hasValidIrtObject() {
 
 //------------------------------------------------------------------------------
 
+bool FullObjectWidget::isCommentable() const {
+  return m_object && m_object->type() != "person" && !m_object->isDeleted();
+}
+
+//------------------------------------------------------------------------------
+
 void FullObjectWidget::onChanged() {
   if (!m_object)
     return;
 
-  m_commentable = m_object->type() != "person" && !m_object->isDeleted();
-  if (m_commentable) {
-    bool isYours = m_author && m_author->isYou();
-
-    m_favourButton->setVisible(true);
-    m_shareButton->setVisible(true);
-    m_deleteButton->setVisible(isYours);
-    m_editButton->setVisible(isYours);
-    m_commentButton->setVisible(true);
-  } else {
-    m_favourButton->setVisible(false);
-    m_shareButton->setVisible(false);
-    m_deleteButton->setVisible(false);
-    m_editButton->setVisible(false);
-    m_commentButton->setVisible(false);
-  }
+  m_commentable = isCommentable();
+  m_favourButton->setVisible(m_commentable);
+  m_shareButton->setVisible(m_commentable);
+  m_commentButton->setVisible(m_commentable);
 
   if (m_object->isDeleted())
     m_imageLabel->setVisible(false);
@@ -302,6 +302,8 @@ void FullObjectWidget::onChanged() {
                                hasValidIrtObject()));
   updateFollowButton();
   updateFollowAuthorButton();
+  updateDeleteEditButtons();
+  
   m_actorWidget->updateMenu();
 
   QString text = m_object->content();
@@ -441,6 +443,20 @@ void FullObjectWidget::updateFollowAuthorButton(bool /*wait*/) {
 
 //------------------------------------------------------------------------------
 
+void FullObjectWidget::updateDeleteEditButtons() {
+  bool isYours = m_author && m_author->isYou();
+
+  if (isCommentable()) {
+    m_deleteButton->setVisible(isYours);
+    m_editButton->setVisible(isYours);
+  } else {
+    m_deleteButton->setVisible(false);
+    m_editButton->setVisible(false);
+  }
+}
+
+//------------------------------------------------------------------------------
+
 void FullObjectWidget::updateImage() {
   FileDownloadManager* fdm = FileDownloadManager::getManager();
 
@@ -807,6 +823,11 @@ QString FullObjectWidget::processText(QString old_text, bool getImages) {
           
 	  FileDownloadManager* fdm = FileDownloadManager::getManager();
 
+	  // only way in Qt to decode html entities in URL
+	  QTextDocument doc;
+	  doc.setHtml(imgSrc);
+	  imgSrc = doc.toPlainText();
+  	  
 	  if (fdm->hasFile(imgSrc)) {
             imagePlaceholder = 
               QString("<a href=\"%2\"><img border=\"0\" src=\"%1\" /></a>").
