@@ -1,5 +1,5 @@
 /*
-  Copyright 2013 Mats Sjöberg
+  Copyright 2013-2015 Mats Sjöberg
   
   This file is part of the Pumpa programme.
 
@@ -22,12 +22,12 @@
 
 #define CLIENT_NAME           "pumpa"
 #define CLIENT_FANCY_NAME     "Pumpa"
-#define CLIENT_VERSION        "0.9"
+#define CLIENT_VERSION        "0.9.1"
 #define CLIENT_ICON           ":/images/pumpa.png"
 
 #define WEBSITE_URL           "https://pumpa.branchable.com/"
 #define MARKUP_DOC_URL        "https://pumpa.branchable.com/markdown/"
-#define BUGTRACKER_URL        "https://gitorious.org/projects/pumpa/issues"
+#define BUGTRACKER_URL        "https://pumpa.branchable.com/bugs/"
 
 #define IMAGE_MAX_WIDTH       320
 #define IMAGE_MAX_HEIGHT      320
