@@ -1,5 +1,5 @@
 /*
-  Copyright 2014 Mats Sjöberg
+  Copyright 2013-2015 Mats Sjöberg
   
   This file is part of the Pumpa programme.
 
@@ -22,6 +22,7 @@
 #include <QInputDialog>
 #include <QLineEdit>
 #include <QClipboard>
+#include <QDesktopServices>
 
 #include "pumpapp.h"
 
@@ -36,7 +37,6 @@ PumpApp::PumpApp(PumpaSettings* settings, QString locale, QWidget* parent) :
   QMainWindow(parent),
   m_nextRequestId(0),
   m_s(settings),
-  m_contextWidget(NULL),
   m_isLoading(false),
   m_wiz(NULL),
   m_messageWindow(NULL),
@@ -170,7 +170,7 @@ PumpApp::PumpApp(PumpaSettings* settings, QString locale, QWidget* parent) :
           this, SLOT(timelineHighlighted(int)));
 
   m_loadIcon = new QLabel(this);
-  m_loadMovie = new QMovie(":/images/loader.gif");
+  m_loadMovie = new QMovie(":/images/loader.gif", QByteArray(), this);
   statusBar()->addPermanentWidget(m_loadIcon);
 
   setWindowTitle(CLIENT_FANCY_NAME);
@@ -199,14 +199,16 @@ PumpApp::~PumpApp() {
 //------------------------------------------------------------------------------
 
 void PumpApp::launchOAuthWizard() {
+  qApp->setQuitOnLastWindowClosed(false);
+
   if (!m_wiz) {
     m_wiz = new OAuthWizard(m_nam, m_oam, this);
     connect(m_wiz, SIGNAL(clientRegistered(QString, QString, QString, QString)),
             this, SLOT(onClientRegistered(QString, QString, QString, QString)));
     connect(m_wiz, SIGNAL(accessTokenReceived(QString, QString)),
             this, SLOT(onAccessTokenReceived(QString, QString)));
-    connect(m_wiz, SIGNAL(rejected()), this, SLOT(exit()));
     connect(m_wiz, SIGNAL(accepted()), this, SLOT(show()));
+    connect(m_wiz, SIGNAL(rejected()), this, SLOT(wizardCancelled()));
   }
   m_wiz->restart();
   m_wiz->show();
@@ -271,12 +273,13 @@ void PumpApp::onSslErrors(QNetworkReply* reply, QList<QSslError> errors) {
   msgBox.setInformativeText(infoText);
   if (!detailText.isEmpty())
     msgBox.setDetailedText(detailText);
-  msgBox.setStandardButtons(QMessageBox::Abort);
+  msgBox.setStandardButtons(QMessageBox::Ignore | QMessageBox::Abort);
   msgBox.setDefaultButton(QMessageBox::Abort);
 
-  msgBox.exec();
-
-  QApplication::quit();
+  if (msgBox.exec() == QMessageBox::Ignore) {
+    reply->ignoreSslErrors();
+    return;
+  }
 }
 
 //------------------------------------------------------------------------------
@@ -423,8 +426,8 @@ void PumpApp::refreshTimeLabels() {
   m_directMajorWidget->refreshTimeLabels();
   m_inboxMinorWidget->refreshTimeLabels();
   m_firehoseWidget->refreshTimeLabels();
-  if (m_contextWidget)
-    m_contextWidget->refreshTimeLabels();
+  for (int i=0; i<m_contextWidgets.size(); ++i)
+    m_contextWidgets[i]->refreshTimeLabels();
 }
 
 //------------------------------------------------------------------------------
@@ -490,7 +493,7 @@ void PumpApp::timelineHighlighted(int feed) {
       return;
 
     QString msg =
-      QString(tr("You have %1 new notifications.")).arg(actsCount);
+      QString(tr("You have %Ln new notification(s).", 0, actsCount));
 
     // If there's only a single post activity we'll make the
     // notification more informative.
@@ -675,6 +678,9 @@ void PumpApp::createActions() {
   aboutQtAction = new QAction(tr("About &Qt"), this);
   connect(aboutQtAction, SIGNAL(triggered()), qApp, SLOT(aboutQt()));
 
+  reportBugAction = new QAction(tr("Report &bug online"), this);
+  connect(reportBugAction, SIGNAL(triggered()), this, SLOT(reportBug()));
+
   newNoteAction = new QAction(tr("New &Note"), this);
   newNoteAction->setShortcut(tr("Ctrl+N"));
   connect(newNoteAction, SIGNAL(triggered()), this, SLOT(newNote()));
@@ -737,6 +743,8 @@ void PumpApp::createMenu() {
   helpMenu = new QMenu(tr("&Help"), this);
   helpMenu->addAction(aboutAction);
   helpMenu->addAction(aboutQtAction);
+  helpMenu->addSeparator();
+  helpMenu->addAction(reportBugAction);
   menuBar()->addMenu(helpMenu);
 }
 
@@ -748,7 +756,15 @@ void PumpApp::preferences() {
 
 //------------------------------------------------------------------------------
 
-void PumpApp::exit() { 
+void PumpApp::wizardCancelled() {
+  qApp->setQuitOnLastWindowClosed(true);
+  if (!haveOAuth())
+    exit();
+}
+
+//------------------------------------------------------------------------------
+
+void PumpApp::exit() {
   qApp->exit();
 }
 
@@ -785,7 +801,7 @@ void PumpApp::about() {
   
   QString mainText = 
     QString("<p><b>%1 %2</b> - %3<br/><a href=\"%4\">%4</a><br/>"
-            + tr("Copyright &copy; 2014 Mats Sj&ouml;berg")
+            + tr("Copyright &copy; 2013-2015 Mats Sj&ouml;berg")
             + " - <a href=\"https://pump.saz.im/sazius\">sazius@pump.saz.im</a>."
             "</p>"
             + tr("<p>Report bugs and feature requests at "
@@ -802,6 +818,12 @@ void PumpApp::about() {
 
 //------------------------------------------------------------------------------
 
+void PumpApp::reportBug() {
+  QDesktopServices::openUrl(QString(BUGTRACKER_URL));
+}
+
+//------------------------------------------------------------------------------
+
 void PumpApp::newNote(QASObject* obj, QASObjectList* to, QASObjectList* cc,
 		      bool edit) {
   if (!m_messageWindow) {
@@ -848,8 +870,9 @@ void PumpApp::fetchAll(bool all) {
 
   if (tabShown(m_firehoseWidget))
     m_firehoseWidget->fetchNewer();
-  if (tabShown(m_contextWidget))
-    m_contextWidget->fetchNewer();
+
+  for (int i=0; i<m_contextWidgets.size(); ++i)
+    m_contextWidgets[i]->fetchNewer();
 
   // These will be reloaded even if not shown, if all=true
   if (all || tabShown(m_followersWidget))
@@ -874,12 +897,17 @@ void PumpApp::loadOlder() {
 //------------------------------------------------------------------------------
 
 bool PumpApp::isShown(QASAbstractObject* obj) {
+  // check context widgets first
+  for (int i=0; i<m_contextWidgets.size(); ++i)
+    if (m_contextWidgets[i]->hasObject(obj))
+      return true;
+
+  // check all other tab widgets
   return m_inboxWidget->hasObject(obj) ||
     m_directMinorWidget->hasObject(obj) ||
     m_directMajorWidget->hasObject(obj) ||
     m_inboxMinorWidget->hasObject(obj) ||
     (tabShown(m_firehoseWidget) && m_firehoseWidget->hasObject(obj)) ||
-    (tabShown(m_contextWidget) && m_contextWidget->hasObject(obj)) ||
     (tabShown(m_followersWidget) && m_followersWidget->hasObject(obj)) ||
     (tabShown(m_followingWidget) && m_followingWidget->hasObject(obj)) ||
     (tabShown(m_favouritesWidget) && m_favouritesWidget->hasObject(obj)) ||
@@ -1038,21 +1066,27 @@ bool PumpApp::tabShown(ASWidget* aw) const {
 //------------------------------------------------------------------------------
 
 void PumpApp::onShowContext(QASObject* obj) {
-  if (!m_contextWidget) {
-    m_contextWidget = new ContextWidget(this);
-    connectCollection(m_contextWidget);
-  }
-  if (!tabShown(m_contextWidget))
-    m_tabWidget->addTab(m_contextWidget, tr("&Context"), true, true);
+  ContextWidget* cw = new ContextWidget(this);
+  connectCollection(cw);
 
-  m_contextWidget->setObject(obj);
-  m_tabWidget->setCurrentWidget(m_contextWidget);
+  m_tabWidget->addTab(cw, tr("&Context"), true, true);
+  cw->setObject(obj);
+  m_tabWidget->setCurrentWidget(cw);
+
+  m_contextWidgets.append(cw);
 }
 
 //------------------------------------------------------------------------------
 
 void PumpApp::closeTab() {
-  m_tabWidget->closeCurrentTab();
+  ContextWidget* cw = 
+    qobject_cast<ContextWidget*>(m_tabWidget->closeCurrentTab());
+  if (cw) {
+    int i = m_contextWidgets.indexOf(cw);
+    if (i != -1)
+      m_contextWidgets.removeAt(i);
+    delete cw;
+  }
 }
 
 //------------------------------------------------------------------------------
@@ -1111,7 +1145,7 @@ void PumpApp::postNote(QString content, QString title,
   obj["objectType"] = "note";
   obj["content"] = addTextMarkup(content, m_s->useMarkdown());
 
-  QString ptitle = processTitle(title);
+  QString ptitle = processTitle(title, false);
   if (!ptitle.isEmpty())
     obj["displayName"] = ptitle;
 
@@ -1126,7 +1160,7 @@ void PumpApp::postEdit(QASObject* obj, QString content, QString title) {
   json["objectType"] = obj->type();
   json["content"] = addTextMarkup(content, m_s->useMarkdown());
 
-  QString ptitle = processTitle(title);
+  QString ptitle = processTitle(title, false);
   if (!ptitle.isEmpty())
     json["displayName"] = ptitle;
 
@@ -1142,7 +1176,7 @@ void PumpApp::postImage(QString msg,
                         RecipientList cc) {
   m_imageObject.clear();
   m_imageObject["content"] = addTextMarkup(msg, m_s->useMarkdown());
-  m_imageObject["displayName"] = processTitle(title);
+  m_imageObject["displayName"] = processTitle(title, false);
 
   m_imageTo = to;
   m_imageCc = cc;
@@ -1413,8 +1447,9 @@ void PumpApp::request(QString endpoint, int response_id,
 
   executeRequest(oaRequest, response_id);
 
+  if (!m_isLoading)
+    notifyMessage(tr("Loading ..."));
   setLoading(true);
-  notifyMessage(tr("Loading ..."));
 }
 
 //------------------------------------------------------------------------------
@@ -1518,19 +1553,21 @@ void PumpApp::onAuthorizedRequestReady(QByteArray response, int rid) {
     QASCollection::getCollection(json, this, id);
   } else if (sid == QAS_ACTIVITY) {
     QASActivity* act = QASActivity::getActivity(json, this);
-    QASObject* obj = act->object();
+    if (act) { // if not a broken activity
+      QASObject* obj = act->object();
 
-    if ((id & QAS_TOGGLE_LIKE) && obj)
-      obj->toggleLiked();
+      if ((id & QAS_TOGGLE_LIKE) && obj)
+	obj->toggleLiked();
 
-    if ((id & QAS_FOLLOW) || (id & QAS_UNFOLLOW)) {
-      QASActor* actor = obj ? obj->asActor() : NULL;
-      if (actor) {
-        bool doFollow = (id & QAS_FOLLOW);
-        followActor(actor, doFollow);
-        notifyMessage(QString(doFollow ? tr("Successfully followed ") :
-                              tr("Successfully unfollowed ")) +
-                      actor->displayNameOrWebFinger());
+      if ((id & QAS_FOLLOW) || (id & QAS_UNFOLLOW)) {
+	QASActor* actor = obj ? obj->asActor() : NULL;
+	if (actor) {
+	  bool doFollow = (id & QAS_FOLLOW);
+	  followActor(actor, doFollow);
+	  notifyMessage(QString(doFollow ? tr("Successfully followed ") :
+				tr("Successfully unfollowed ")) +
+			actor->displayNameOrWebFinger());
+	}
       }
     }
   } else if (sid == QAS_OBJECTLIST) {
