@@ -1,5 +1,5 @@
 /*
-  Copyright 2013 Mats Sjöberg
+  Copyright 2013-2015 Mats Sjöberg
   
   This file is part of the Pumpa programme.
 
@@ -45,10 +45,9 @@ public:
 
   QString displayNameOrYou() const { return isYou() ? "You" : displayName(); }
   bool isYou() const { return m_isYou; }
-  void setYou() { m_isYou = true; }
+  void setYou();
 
-  bool followed() const { return m_followed; }
-  bool followedJson() const { return m_followed_json; }
+  bool followed() const;
   void setFollowed(bool b);
   QString summary() const { return m_summary; }
   QString location() const { return m_location; }
@@ -61,6 +60,7 @@ public:
 private:
   bool m_followed;
   bool m_followed_json;
+  bool m_followed_set;
   bool m_isYou;
   QString m_summary;
   QString m_location;
